==> phplist-2.10.14p1.tgz: lists/admin/lan/es/send.php <==
<?php

## notes to translators:
# do not translate anything in square brackets: eg [RSS]

$lan = array (
  'noaccess' => 'Este mensaje no existe, o bien usted no tiene acceso
  a &eacute;l',
  'htmlusedwarning' => 'Atenci&oacute;n: Usted indic&oacute; que el
  mensaje no era HTML, pero contiene etiquetas HTML. Esto puede causar
  errores',
  'adding' => 'A&ntilde;adiendo',
  'longmimetype' => 'El tipo MIME tiene m&aacute;s de 255
  caracteres. Esto causar&aacute; graves problemas',
  'addingattachment' => 'Se a&ntilde;adi&oacute; un fichero adjunto ',
  'uploadfailed' => 'El fichero cargado no se recibi&oacute;
  correctamente, est&aacute; vac&iacute;o',
  'saved' => 'Mensaje salvado',
  'added' => 'Mensaje a&ntilde;adido',
  'queued' => 'Mensaje colocado en la cola de env&iacute;o',
  'processqueue' => 'Procesar la cola de mensajes',
  'errorsubject' => 'Disculpe, hay caracteres no v&aacute;lidos en el
  campo &#171;Asunto&#187;.',
  'errorfrom' => 'Disculpe, hay caracteres no v&aacute;lidos en el
  campo &#171;De&#187;.',
  'enterfrom' => 'Rellene el campo &#171;De&#187;.',
  'entermessage' => 'Rellene el mensaje',
  'entersubject' => 'Rellene el campo &#171;Asunto&#187;',
  'duplicateattribute' => 'Error: solo puede utilizar un  atributo en
  una &uacute;nica regla',
  'selectlist' => 'Escoja la(s) lista(s) a la(s) que hay que enviar el
  mensaje',
  'notargetemail' => 'No se seleccion&oacute; ning&uacute;n email de
  destino para la prueba.',
  'emailnotfound' => 'No se encontraron emails a los que enviar el
  mensaje de prueba.',
  'sentemailto' => 'Mensaje de prueba enviado a',
  'removedattachment' => 'Se retir&oacute; el fichero adjunto ',
  'existingcriteria' => 'Criterios existentes',
  'remove' => 'Eliminar',
  'calculating' => 'Calculando',
  'calculate' => 'Calcular',
  'content' => 'Contenido',
  'format' => 'Formato',
  'attach' => 'Adjunto',
  'scheduling' => 'Calendario',
  'criteria' => 'Criterios',
  'lists' => 'Listas',
  'unsavedchanges' => 'Cuidado!  No salv&oacute; los cambios!\nHaga clic en OK para continuar sin salvarlos,\no ANULAR para no cambiar de p&aacute;gina y poder salvar los cambios.',
  'whatisprepare' => '&#191;Qu&eacute; es &#171;Preparar un mensaje&#187;?',
  'subject' => 'Asunto',
  'fromline' => 'campo &#171;De&#187;',
  'embargoeduntil' => 'Detenido hasta',
  'repeatevery' => 'Repetir el mensaje cada',
  'norepetition' => 'sin repeticiones',
  'hour' => 'Hora',
  'day' => 'D&iacute;a',
  'week' => 'Semana',
  'repeatuntil' => 'Repetir hasta',
  'format' => 'Formato',
  'autodetect' => 'Auto detectar',
  'sendas' => 'Enviar como',
  'html' => 'HTML',
  'text' => 'text plano',
  'pdf' => 'PDF',
//  'textandhtml' => 'Texto y HTML', //obsolete by bug 0009687
  'textandpdf' => 'Texto y PDF',
  'usetemplate' => 'Utilizar plantilla',
  'selectone' => 'escoja uno',
  'rssintro' => 'Si quiere usar este mensaje como plantilla para
  enviar canales RSS escoja la frecuencia con la que se debe utilizar,
  e incluya [RSS] en su mensaje para indicar d&oacute;nde debe ir la
  lista de elementos.',
  'none' => 'ninguno',
  'message' => 'Mensaje',
  'expand' => 'expandir',
  'plaintextversion' => 'Versi&oacute; en texto plano del mensaje',
  'messagefooter' => 'Pie de mensaje',
  'messagefooterexplanation1' => 'Utilice <b>[UNSUBSCRIBE]</b> para incluir una URL &uacute;nica para cada usuario, en la que se pueda desinscribir.',
  'messagefooterexplanation2' => 'Utilice <b>[PREFERENCES]</b> para incluir una URL &uacute;nica para cada usuario, en la que pueda actualizar sus datos',
  'messagefooterexplanation3' => 'Utilice <b>[FORWARD]</b> para agregar una URL personalizada para reenviar el mensaje a otra persona.',
  'addattachments' => 'Adjuntar ficheros a su mensaje.',
  'uploadlimits' => 'El servidor ha establecido los siguientes
  l&iacute;mites en la carga de ficheros',
  'maxtotaldata' => 'Tama&ntilde;o m&aacute;ximo total de los datos que
  se env&iacute;en al servidor',
  'maxfileupload' => 'Tama&ntilde;o m&aacute;ximo de cada fichero',
  'currentattachments' => 'Ficheros adjuntos actuales',
  'filename' => 'Nombre de fichero',
  'desc' => 'descripci&oacute;n',# short for description
  'size' => 'tama&ntilde;o',
  'file' => 'fichero',
  'del' => 'eliminar', # short for delete
  'newattachment' => 'Nuevo fichero adjunto',
  'addandsave' => 'A&ntilde;adir (y salvar)',
  'pathtofile' => 'Ruta de acceso al fichero en el servidor',
  'attachmentdescription' => 'Descripci&oacute;n del fichero adjunto',
  'delchecked' => 'Eliminar los que est&aacute;n marcados',
  'sendtestmessage' => 'Enviar mensaje de prueba',
  'toemailaddresses' => ' a los emails',
  'sendtestexplain' => '(separe las direcciones con comas - todos
  deben ser usuarios)',
  'criteriaexplanation' => '
        <p><b>Escoja los criterios de este mensaje:</b>
        <ol>
        <li>para usar un criterio, marque la casilla que hay a su lado
        <li>despu&eacute;s marque el radiobot&oacute;n que est&aacute;
  junto al atribut que quiere usar
        <li>despu&eacute;s escoja los valores de los atributos que
  definen a qui&eacute;n quiere enviar el mensaje
        <i>Nota:</i> Se enviar&aacute; el mensaje a los usuarios que
  cumplan el <i>Criterio 1</i> <b>Y</b> el <i>Criterio 2</i> etc',
  'criterion' => 'Criterio',
  'usethisone' => 'Usar este',
  'or' => 'o', # "alternative" ie this or this
  'is' => 'es',
  'isnot' => 'no es',
  'isbefore' => 'es anterior a', # date and time wise
  'isafter' => 'es posterior a', # date and time wise
  'nocriteria' => 'En este momento no hay atributos disponibles para
  enviar un mensaje. El mensaje se enviar&aacute; a todos los usuarios
  de las listas seleccionadas',
  'checked' => 'Seleccionado', # as for checkbox
  'unchecked' => 'No seleccionado', # as for checkbox
  'buggywithie' => 'Atenci&oacute;n: esta funci&oacute;n da errores y
  no es fiable con IE.\nEs preferible utilizar Mozilla, Firefox u
  Opera\nTambi&eacute;n puede desconectar STACKED_ATTRIBUTE_SELECTION
  en su fichero de configuraci&oacute;n', # Don't translate STACKED_ATTRIBUTE_SELECTION
  'matchallrules' => 'Concuerda con todas estas normas',
  'matchanyrules' => 'Concuerda con alguna de estas normas',
  'addcriterion' => 'A&ntilde;adir criterio',
  'saveasdraft' => 'Salvar borrador del mensaje',
  'savechanges' => 'Salvar cambios',
  'selectattribute' => 'seleccionar atributo',
  'dd-mm-yyyy' => 'dd-mm-yyyy', # it's essential that the format is the same (ie dd-mm-yyyy)

  # above is all from send_core

  'selectlists' => 'Escoja las listas a las que lo quiere enviar',
  'alllists' => 'Todas las listas',
  'listactive' => 'La lista est&aacute; activa',
  'listnotactive' => 'La lista no est&aacute; activa',
  'selectexcludelist' => 'Escoja las listas que hay que excluir',
  'excludelistexplain' => 'El mensaje se enviar&aacute; a los usuarios
  que son miembros de las listas enumeradas m&aacute;s arriba, a no ser que sean
  miembros de alguna de las listas que escoja aqu&iacute;.',
  'nolistsavailable' => 'Disculpe, no hay ninguna lista disponible',
  'sendmessage' => 'Enviar el mensaje a las listas seleccionadas',
  'warnnopearhttprequest' => 'Est&aacute; intentando enviar una URL
  remota, pero PEAR::HTTP/Request no est&aacute; disponible, de modo
  que esto no va a funcionar',
  #


  ### new in 2.9.5
  'Misc' => 'Varios',
  'email to alert when sending of this message starts' => 'Email al que avisar cuando comienze el env&iacute;o de este mensaje.',
  'email to alert when sending of this message has finished' => 'Email al que avisar cuando termine el env&iacute;o de este mensaje.',
  'separate multiple with a comma' => 'Si son varios sep&aacute;relos con comas.',
);

?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/es/send.php <==
<?php

## notes to translators:
# do not translate anything in square brackets: eg [RSS]

$lan = array (
  'noaccess' => 'Este mensaje no existe, o bien usted no tiene acceso
  a &eacute;l',
  'htmlusedwarning' => 'Atenci&oacute;n: Usted indic&oacute; que el
  mensaje no era HTML, pero contiene etiquetas HTML. Esto puede causar
  errores',
  'adding' => 'A&ntilde;adiendo',
  'longmimetype' => 'El tipo MIME tiene m&aacute;s de 255
  caracteres. Esto causar&aacute; graves problemas',
  'addingattachment' => 'Se a&ntilde;adi&oacute; un fichero adjunto ',
  'uploadfailed' => 'El fichero cargado no se recibi&oacute;
  correctamente, est&aacute; vac&iacute;o',
  'saved' => 'Mensaje salvado',
  'added' => 'Mensaje a&ntilde;adido',
  'queued' => 'Mensaje colocado en la cola de env&iacute;o',
  'processqueue' => 'Procesar la cola de mensajes',
  'errorsubject' => 'Disculpe, hay caracteres no v&aacute;lidos en el
  campo &#171;Asunto&#187;.',
  'errorfrom' => 'Disculpe, hay caracteres no v&aacute;lidos en el
  campo &#171;De&#187;.',
  'enterfrom' => 'Rellene el campo &#171;De&#187;.',
  'entermessage' => 'Rellene el mensaje',
  'entersubject' => 'Rellene el campo &#171;Asunto&#187;',
  'duplicateattribute' => 'Error: solo puede utilizar un  atributo en
  una &uacute;nica regla',
  'selectlist' => 'Escoja la(s) lista(s) a la(s) que hay que enviar el
  mensaje',
  'notargetemail' => 'No se seleccion&oacute; ning&uacute;n email de
  destino para la prueba.',
  'emailnotfound' => 'No se encontraron emails a los que enviar el
  mensaje de prueba.',
  'sentemailto' => 'Mensaje de prueba enviado a',
  'removedattachment' => 'Se retir&oacute; el fichero adjunto ',
  'existingcriteria' => 'Criterios existentes',
  'remove' => 'Eliminar',
  'calculating' => 'Calculando',
  'calculate' => 'Calcular',
  'content' => 'Contenido',
  'format' => 'Formato',
  'attach' => 'Adjunto',
  'scheduling' => 'Calendario',
  'criteria' => 'Criterios',
  'lists' => 'Listas',
  'unsavedchanges' => 'Cuidado!  No salv&oacute; los cambios!\nHaga clic en OK para continuar sin salvarlos,\no ANULAR para no cambiar de p&aacute;gina y poder salvar los cambios.',
  'whatisprepare' => '&#191;Qu&eacute; es &#171;Preparar un mensaje&#187;?',
  'subject' => 'Asunto',
  'fromline' => 'campo &#171;De&#187;',
  'embargoeduntil' => 'Detenido hasta',
  'repeatevery' => 'Repetir el mensaje cada',
  'norepetition' => 'sin repeticiones',
  'hour' => 'Hora',
  'day' => 'D&iacute;a',
  'week' => 'Semana',
  'repeatuntil' => 'Repetir hasta',
  'format' => 'Formato',
  'autodetect' => 'Auto detectar',
  'sendas' => 'Enviar como',
  'html' => 'HTML',
  'text' => 'text plano',
  'pdf' => 'PDF',
//  'textandhtml' => 'Texto y HTML', //obsolete by bug 0009687
  'textandpdf' => 'Texto y PDF',
  'usetemplate' => 'Utilizar patr&oacute;n',
  'selectone' => 'escoja uno',
  'rssintro' => 'Si quiere usar este mensaje como patr&oacute;n para
  enviar canales RSS escoja la frecuencia con la que se debe utilizar,
  e incluya [RSS] en su mensaje para indicar d&oacute;nde debe ir la
  lista de elementos.',
  'none' => 'ninguno',
  'message' => 'Mensaje',
  'expand' => 'expandir',
  'plaintextversion' => 'Versi&oacute; en texto plano del mensaje',
  'messagefooter' => 'Pie de mensaje',
  'messagefooterexplanation1' => 'Utilice <b>[UNSUBSCRIBE]</b> para incluir una URL &uacute;nica para cada usuario, en la que se pueda desinscribir.',
  'messagefooterexplanation2' => 'Utilice <b>[PREFERENCES]</b> para incluir una URL &uacute;nica para cada usuario, en la que pueda actualizar sus datos',
  'messagefooterexplanation3' => 'Utilice <b>[FORWARD]</b> para agregar una URL personalizada para reenviar el mensaje a otra persona.',
  'addattachments' => 'Adjuntar ficheros a su mensaje.',
  'uploadlimits' => 'El servidor ha establecido los siguientes
  l&iacute;mites en la carga de ficheros',
  'maxtotaldata' => 'Tama&ntilde;o m&aacute;ximo total de los datos que
  se env&iacute;en al servidor',
  'maxfileupload' => 'Tama&ntilde;o m&aacute;ximo de cada fichero',
  'currentattachments' => 'Ficheros adjuntos actuales',
  'filename' => 'Nombre de fichero',
  'desc' => 'descripci&oacute;n',# short for description
  'size' => 'tama&ntilde;o',
  'file' => 'fichero',
  'del' => 'eliminar', # short for delete
  'newattachment' => 'Nuevo fichero adjunto',
  'addandsave' => 'A&ntilde;adir (y salvar)',
  'pathtofile' => 'Ruta de acceso al fichero en el servidor',
  'attachmentdescription' => 'Descripci&oacute;n del fichero adjunto',
  'delchecked' => 'Eliminar los que est&aacute;n marcados',
  'sendtestmessage' => 'Enviar mensaje de prueba',
  'toemailaddresses' => ' a los emails',
  'sendtestexplain' => '(separe las direcciones con comas - todos
  deben ser usuarios)',
  'criteriaexplanation' => '
        <p><b>Escoja los criterios de este mensaje:</b>
        <ol>
        <li>para usar un criterio, marque la casilla que hay a su lado
        <li>despu&eacute;s marque el radiobot&oacute;n que est&aacute;
  junto al atribut que quiere usar
        <li>despu&eacute;s escoja los valores de los atributos que
  definen a qui&eacute;n quiere enviar el mensaje
        <i>Nota:</i> Se enviar&aacute; el mensaje a los usuarios que
  cumplan el <i>Criterio 1</i> <b>Y</b> el <i>Criterio 2</i> etc',
  'criterion' => 'Criterio',
  'usethisone' => 'Usar este',
  'or' => 'o', # "alternative" ie this or this
  'is' => 'es',
  'isnot' => 'no es',
  'isbefore' => 'es anterior a', # date and time wise
  'isafter' => 'es posterior a', # date and time wise
  'nocriteria' => 'En este momento no hay atributos disponibles para
  enviar un mensaje. El mensaje se enviar&aacute; a todos los usuarios
  de las listas seleccionadas',
  'checked' => 'Seleccionado', # as for checkbox
  'unchecked' => 'No seleccionado', # as for checkbox
  'buggywithie' => 'Atenci&oacute;n: esta funci&oacute;n da errores y
  no es fiable con IE.\nEs preferible utilizar Mozilla, Firefox u
  Opera\nTambi&eacute;n puede desconectar STACKED_ATTRIBUTE_SELECTION
  en su fichero de configuraci&oacute;n', # Don't translate STACKED_ATTRIBUTE_SELECTION
  'matchallrules' => 'Concuerda con todas estas normas',
  'matchanyrules' => 'Concuerda con alguna de estas normas',
  'addcriterion' => 'A&ntilde;adir criterio',
  'saveasdraft' => 'Salvar borrador del mensaje',
  'savechanges' => 'Salvar cambios',
  'selectattribute' => 'seleccionar atributo',
  'dd-mm-yyyy' => 'dd-mm-yyyy', # it's essential that the format is the same (ie dd-mm-yyyy)

  # above is all from send_core

  'selectlists' => 'Escoja las listas a las que lo quiere enviar',
  'alllists' => 'Todas las listas',
  'listactive' => 'La lista est&aacute; activa',
  'listnotactive' => 'La lista no est&aacute; activa',
  'selectexcludelist' => 'Escoja las listas que hay que excluir',
  'excludelistexplain' => 'El mensaje se enviar&aacute; a los usuarios
  que son miembros de las listas enumeradas m&aacute;s arriba, a no ser que sean
  miembros de alguna de las listas que escoja aqu&iacute;.',
  'nolistsavailable' => 'Disculpe, no hay ninguna lista disponible',
  'sendmessage' => 'Enviar el mensaje a las listas seleccionadas',
  'warnnopearhttprequest' => 'Est&aacute; intentando enviar una URL
  remota, pero PEAR::HTTP/Request no est&aacute; disponible, de modo
  que esto no va a funcionar',
  #


  ### new in 2.9.5
  'Misc' => 'Varios',
  'email to alert when sending of this message starts' => 'Email al que avisar cuando comienze el env&iacute;o de este mensaje.',
  'email to alert when sending of this message has finished' => 'Email al que avisar cuando termine el env&iacute;o de este mensaje.',
  'separate multiple with a comma' => 'Si son varios sep&aacute;relos con comas.',
);

?>
